==> zio-aws-chimesdkmediapipelines_2.12-6.20.56.2-sources.jar: zio/aws/chimesdkmediapipelines/model/TimestampRange.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.ZIO
import zio.aws.chimesdkmediapipelines.model.primitives.Timestamp
import zio.aws.core.BuilderHelper
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class TimestampRange(
    startTimestamp: Timestamp,
    endTimestamp: Timestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange = {
    import TimestampRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange
      .builder()
      .startTimestamp(Timestamp.unwrap(startTimestamp): Instant)
      .endTimestamp(Timestamp.unwrap(endTimestamp): Instant)
      .build()
  }
  def asReadOnly: zio.aws.chimesdkmediapipelines.model.TimestampRange.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.TimestampRange.wrap(buildAwsValue())
}
object TimestampRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmediapipelines.model.TimestampRange =
      zio.aws.chimesdkmediapipelines.model
        .TimestampRange(startTimestamp, endTimestamp)
    def startTimestamp: Timestamp
    def endTimestamp: Timestamp
    def getStartTimestamp: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(startTimestamp)
    def getEndTimestamp: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(endTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange
  ) extends zio.aws.chimesdkmediapipelines.model.TimestampRange.ReadOnly {
    override val startTimestamp: Timestamp =
      zio.aws.chimesdkmediapipelines.model.primitives
        .Timestamp(impl.startTimestamp())
    override val endTimestamp: Timestamp =
      zio.aws.chimesdkmediapipelines.model.primitives
        .Timestamp(impl.endTimestamp())
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange
  ): zio.aws.chimesdkmediapipelines.model.TimestampRange.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-chimesdkmediapipelines_3-6.20.42.2-sources.jar: zio/aws/chimesdkmediapipelines/model/TimestampRange.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.ZIO
import zio.aws.chimesdkmediapipelines.model.primitives.Timestamp
import zio.aws.core.BuilderHelper
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class TimestampRange(
    startTimestamp: Timestamp,
    endTimestamp: Timestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange = {
    import TimestampRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange
      .builder()
      .startTimestamp(Timestamp.unwrap(startTimestamp): Instant)
      .endTimestamp(Timestamp.unwrap(endTimestamp): Instant)
      .build()
  }
  def asReadOnly: zio.aws.chimesdkmediapipelines.model.TimestampRange.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.TimestampRange.wrap(buildAwsValue())
}
object TimestampRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmediapipelines.model.TimestampRange =
      zio.aws.chimesdkmediapipelines.model
        .TimestampRange(startTimestamp, endTimestamp)
    def startTimestamp: Timestamp
    def endTimestamp: Timestamp
    def getStartTimestamp: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(startTimestamp)
    def getEndTimestamp: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(endTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange
  ) extends zio.aws.chimesdkmediapipelines.model.TimestampRange.ReadOnly {
    override val startTimestamp: Timestamp =
      zio.aws.chimesdkmediapipelines.model.primitives
        .Timestamp(impl.startTimestamp())
    override val endTimestamp: Timestamp =
      zio.aws.chimesdkmediapipelines.model.primitives
        .Timestamp(impl.endTimestamp())
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.TimestampRange
  ): zio.aws.chimesdkmediapipelines.model.TimestampRange.ReadOnly = new Wrapper(
    impl
  )
}
